@@ -353,8 +353,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah enabled */
   fx_wah_wah_channel->wah_wah_enabled = g_object_new(AGS_TYPE_PORT,
 						     "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						     "specifier", ags_fx_wah_wah_channel_specifier[position],
-						     "control-port", ags_fx_wah_wah_channel_control_port[position],
+						     "specifier", "./wah-wah-enabled[0]",
+						     "control-port", "1/11",
 						     "port-value-is-pointer", FALSE,
 						     "port-value-type", G_TYPE_FLOAT,
 						     "port-value-size", sizeof(gfloat),
@@ -375,8 +375,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah length mode */
   fx_wah_wah_channel->wah_wah_length_mode = g_object_new(AGS_TYPE_PORT,
 							 "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-							 "specifier", ags_fx_wah_wah_channel_specifier[position],
-							 "control-port", ags_fx_wah_wah_channel_control_port[position],
+							 "specifier", "./wah-wah-length-mode[0]",
+							 "control-port", "2/11",
 							 "port-value-is-pointer", FALSE,
 							 "port-value-type", G_TYPE_FLOAT,
 							 "port-value-size", sizeof(gfloat),
@@ -397,8 +397,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah fixed length */
   fx_wah_wah_channel->wah_wah_fixed_length = g_object_new(AGS_TYPE_PORT,
 							  "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-							  "specifier", ags_fx_wah_wah_channel_specifier[position],
-							  "control-port", ags_fx_wah_wah_channel_control_port[position],
+							  "specifier", "./wah-wah-fixed-length[0]",
+							  "control-port", "3/11",
 							  "port-value-is-pointer", FALSE,
 							  "port-value-type", G_TYPE_FLOAT,
 							  "port-value-size", sizeof(gfloat),
@@ -419,8 +419,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah attack */
   fx_wah_wah_channel->wah_wah_attack = g_object_new(AGS_TYPE_PORT,
 						    "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						    "specifier", ags_fx_wah_wah_channel_specifier[position],
-						    "control-port", ags_fx_wah_wah_channel_control_port[position],
+						    "specifier", "./wah-wah-attack[0]",
+						    "control-port", "4/11",
 						    "port-value-is-pointer", FALSE,
 						    "port-value-type", G_TYPE_FLOAT,
 						    "port-value-size", sizeof(gfloat),
@@ -441,8 +441,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah decay */
   fx_wah_wah_channel->wah_wah_decay = g_object_new(AGS_TYPE_PORT,
 						   "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						   "specifier", ags_fx_wah_wah_channel_specifier[position],
-						   "control-port", ags_fx_wah_wah_channel_control_port[position],
+						   "specifier", "./wah-wah-decay[0]",
+						   "control-port", "5/11",
 						   "port-value-is-pointer", FALSE,
 						   "port-value-type", G_TYPE_FLOAT,
 						   "port-value-size", sizeof(gfloat),
@@ -463,8 +463,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah sustain */
   fx_wah_wah_channel->wah_wah_sustain = g_object_new(AGS_TYPE_PORT,
 						     "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						     "specifier", ags_fx_wah_wah_channel_specifier[position],
-						     "control-port", ags_fx_wah_wah_channel_control_port[position],
+						     "specifier", "./wah-wah-sustain[0]",
+						     "control-port", "6/11",
 						     "port-value-is-pointer", FALSE,
 						     "port-value-type", G_TYPE_FLOAT,
 						     "port-value-size", sizeof(gfloat),
@@ -485,8 +485,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah release */
   fx_wah_wah_channel->wah_wah_release = g_object_new(AGS_TYPE_PORT,
 						     "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						     "specifier", ags_fx_wah_wah_channel_specifier[position],
-						     "control-port", ags_fx_wah_wah_channel_control_port[position],
+						     "specifier", "./wah-wah-release[0]",
+						     "control-port", "7/11",
 						     "port-value-is-pointer", FALSE,
 						     "port-value-type", G_TYPE_FLOAT,
 						     "port-value-size", sizeof(gfloat),
@@ -507,8 +507,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah ratio */
   fx_wah_wah_channel->wah_wah_ratio = g_object_new(AGS_TYPE_PORT,
 						   "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						   "specifier", ags_fx_wah_wah_channel_specifier[position],
-						   "control-port", ags_fx_wah_wah_channel_control_port[position],
+						   "specifier", "./wah-wah-ratio[0]",
+						   "control-port", "8/11",
 						   "port-value-is-pointer", FALSE,
 						   "port-value-type", G_TYPE_FLOAT,
 						   "port-value-size", sizeof(gfloat),
@@ -529,8 +529,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah LFO depth */
   fx_wah_wah_channel->wah_wah_lfo_depth = g_object_new(AGS_TYPE_PORT,
 						       "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						       "specifier", ags_fx_wah_wah_channel_specifier[position],
-						       "control-port", ags_fx_wah_wah_channel_control_port[position],
+						       "specifier", "./wah-wah-lfo-depth[0]",
+						       "control-port", "9/11",
 						       "port-value-is-pointer", FALSE,
 						       "port-value-type", G_TYPE_FLOAT,
 						       "port-value-size", sizeof(gfloat),
@@ -551,8 +551,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah LFO freq */
   fx_wah_wah_channel->wah_wah_lfo_freq = g_object_new(AGS_TYPE_PORT,
 						       "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						       "specifier", ags_fx_wah_wah_channel_specifier[position],
-						       "control-port", ags_fx_wah_wah_channel_control_port[position],
+						       "specifier", "./wah-wah-lfo-freq[0]",
+						       "control-port", "10/11",
 						       "port-value-is-pointer", FALSE,
 						       "port-value-type", G_TYPE_FLOAT,
 						       "port-value-size", sizeof(gfloat),
@@ -573,8 +573,8 @@ ags_fx_wah_wah_channel_init(AgsFxWahWahChannel *fx_wah_wah_channel)
   /* wah-wah tuning */
   fx_wah_wah_channel->wah_wah_tuning = g_object_new(AGS_TYPE_PORT,
 						    "plugin-name", ags_fx_wah_wah_channel_plugin_name,
-						    "specifier", ags_fx_wah_wah_channel_specifier[position],
-						    "control-port", ags_fx_wah_wah_channel_control_port[position],
+						    "specifier", "./wah-wah-tuning[0]",
+						    "control-port", "11/11",
 						    "port-value-is-pointer", FALSE,
 						    "port-value-type", G_TYPE_FLOAT,
 						    "port-value-size", sizeof(gfloat),
